Crate gl_client

Crate gl_client 

Greenlight client library to schedule nodes, interact with them and sign off on signature requests.

Re-exports

pub use lightning_signer::bitcoin;
pub use lightning_signer::lightning;
pub use lightning_signer::lightning_invoice;

Modules

credentials
export
Utilities to work with export/backup files.
lnurl
metrics
node
Interact with a node running on greenlight.
pairing
The pairing service that pairs signer-less clients with existing signers.
pb
Generated protobuf messages and client stubs.
persist
runes
scheduler
Register, recover and schedule your nodes on greenlight.
signer
Your keys, your coins!
tls
Helpers to configure the mTLS connection authentication.
util
utils
Tools to interact with a node running on greenlight.

Enums

Error