pub struct MockLnUrlHttpClient { /* private fields */ }Implementations
Sourceimpl MockLnUrlHttpClient
impl MockLnUrlHttpClient
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockLnUrlHttpClient
impl MockLnUrlHttpClient
Sourcepub fn expect_get_pay_request_response(&mut self) -> &mut Expectation<'static>
pub fn expect_get_pay_request_response(&mut self) -> &mut Expectation<'static>
Create an Expectation for mocking the get_pay_request_response method
Sourcepub fn expect_get_pay_request_callback_response(
&mut self,
) -> &mut Expectation<'static>
pub fn expect_get_pay_request_callback_response( &mut self, ) -> &mut Expectation<'static>
Create an Expectation for mocking the get_pay_request_callback_response method
Sourcepub fn expect_get_withdrawal_request_response(
&mut self,
) -> &mut Expectation<'static>
pub fn expect_get_withdrawal_request_response( &mut self, ) -> &mut Expectation<'static>
Create an Expectation for mocking the get_withdrawal_request_response method
Sourcepub fn expect_send_invoice_for_withdraw_request(
&mut self,
) -> &mut Expectation<'static>
pub fn expect_send_invoice_for_withdraw_request( &mut self, ) -> &mut Expectation<'static>
Create an Expectation for mocking the send_invoice_for_withdraw_request method
Sourcepub fn expect_get_json(&mut self) -> &mut Expectation<'static>
pub fn expect_get_json(&mut self) -> &mut Expectation<'static>
Create an Expectation for mocking the get_json method