pub struct ListconfigsConfigs {Show 71 fields
pub conf: Option<ListconfigsConfigsConf>,
pub developer: Option<ListconfigsConfigsDeveloper>,
pub clear_plugins: Option<ListconfigsConfigsClearplugins>,
pub disable_mpp: Option<ListconfigsConfigsDisablempp>,
pub mainnet: Option<ListconfigsConfigsMainnet>,
pub regtest: Option<ListconfigsConfigsRegtest>,
pub signet: Option<ListconfigsConfigsSignet>,
pub testnet: Option<ListconfigsConfigsTestnet>,
pub important_plugin: Option<ListconfigsConfigsImportantplugin>,
pub plugin: Option<ListconfigsConfigsPlugin>,
pub plugin_dir: Option<ListconfigsConfigsPlugindir>,
pub lightning_dir: Option<ListconfigsConfigsLightningdir>,
pub network: Option<ListconfigsConfigsNetwork>,
pub allow_deprecated_apis: Option<ListconfigsConfigsAllowdeprecatedapis>,
pub rpc_file: Option<ListconfigsConfigsRpcfile>,
pub disable_plugin: Option<ListconfigsConfigsDisableplugin>,
pub always_use_proxy: Option<ListconfigsConfigsAlwaysuseproxy>,
pub daemon: Option<ListconfigsConfigsDaemon>,
pub wallet: Option<ListconfigsConfigsWallet>,
pub large_channels: Option<ListconfigsConfigsLargechannels>,
pub experimental_dual_fund: Option<ListconfigsConfigsExperimentaldualfund>,
pub experimental_splicing: Option<ListconfigsConfigsExperimentalsplicing>,
pub experimental_onion_messages: Option<ListconfigsConfigsExperimentalonionmessages>,
pub experimental_offers: Option<ListconfigsConfigsExperimentaloffers>,
pub experimental_shutdown_wrong_funding: Option<ListconfigsConfigsExperimentalshutdownwrongfunding>,
pub experimental_peer_storage: Option<ListconfigsConfigsExperimentalpeerstorage>,
pub experimental_anchors: Option<ListconfigsConfigsExperimentalanchors>,
pub database_upgrade: Option<ListconfigsConfigsDatabaseupgrade>,
pub rgb: Option<ListconfigsConfigsRgb>,
pub alias: Option<ListconfigsConfigsAlias>,
pub pid_file: Option<ListconfigsConfigsPidfile>,
pub ignore_fee_limits: Option<ListconfigsConfigsIgnorefeelimits>,
pub watchtime_blocks: Option<ListconfigsConfigsWatchtimeblocks>,
pub max_locktime_blocks: Option<ListconfigsConfigsMaxlocktimeblocks>,
pub funding_confirms: Option<ListconfigsConfigsFundingconfirms>,
pub cltv_delta: Option<ListconfigsConfigsCltvdelta>,
pub cltv_final: Option<ListconfigsConfigsCltvfinal>,
pub commit_time: Option<ListconfigsConfigsCommittime>,
pub fee_base: Option<ListconfigsConfigsFeebase>,
pub rescan: Option<ListconfigsConfigsRescan>,
pub fee_per_satoshi: Option<ListconfigsConfigsFeepersatoshi>,
pub max_concurrent_htlcs: Option<ListconfigsConfigsMaxconcurrenthtlcs>,
pub htlc_minimum_msat: Option<ListconfigsConfigsHtlcminimummsat>,
pub htlc_maximum_msat: Option<ListconfigsConfigsHtlcmaximummsat>,
pub max_dust_htlc_exposure_msat: Option<ListconfigsConfigsMaxdusthtlcexposuremsat>,
pub min_capacity_sat: Option<ListconfigsConfigsMincapacitysat>,
pub addr: Option<ListconfigsConfigsAddr>,
pub announce_addr: Option<ListconfigsConfigsAnnounceaddr>,
pub bind_addr: Option<ListconfigsConfigsBindaddr>,
pub offline: Option<ListconfigsConfigsOffline>,
pub autolisten: Option<ListconfigsConfigsAutolisten>,
pub proxy: Option<ListconfigsConfigsProxy>,
pub disable_dns: Option<ListconfigsConfigsDisabledns>,
pub announce_addr_discovered: Option<ListconfigsConfigsAnnounceaddrdiscovered>,
pub announce_addr_discovered_port: Option<ListconfigsConfigsAnnounceaddrdiscoveredport>,
pub encrypted_hsm: Option<ListconfigsConfigsEncryptedhsm>,
pub rpc_file_mode: Option<ListconfigsConfigsRpcfilemode>,
pub log_level: Option<ListconfigsConfigsLoglevel>,
pub log_prefix: Option<ListconfigsConfigsLogprefix>,
pub log_file: Option<ListconfigsConfigsLogfile>,
pub log_timestamps: Option<ListconfigsConfigsLogtimestamps>,
pub force_feerates: Option<ListconfigsConfigsForcefeerates>,
pub subdaemon: Option<ListconfigsConfigsSubdaemon>,
pub fetchinvoice_noconnect: Option<ListconfigsConfigsFetchinvoicenoconnect>,
pub accept_htlc_tlv_types: Option<ListconfigsConfigsAccepthtlctlvtypes>,
pub tor_service_password: Option<ListconfigsConfigsTorservicepassword>,
pub announce_addr_dns: Option<ListconfigsConfigsAnnounceaddrdns>,
pub require_confirmed_inputs: Option<ListconfigsConfigsRequireconfirmedinputs>,
pub commit_fee: Option<ListconfigsConfigsCommitfee>,
pub commit_feerate_offset: Option<ListconfigsConfigsCommitfeerateoffset>,
pub autoconnect_seeker_peers: Option<ListconfigsConfigsAutoconnectseekerpeers>,
}Fields
conf: Option<ListconfigsConfigsConf>developer: Option<ListconfigsConfigsDeveloper>clear_plugins: Option<ListconfigsConfigsClearplugins>disable_mpp: Option<ListconfigsConfigsDisablempp>mainnet: Option<ListconfigsConfigsMainnet>regtest: Option<ListconfigsConfigsRegtest>signet: Option<ListconfigsConfigsSignet>testnet: Option<ListconfigsConfigsTestnet>important_plugin: Option<ListconfigsConfigsImportantplugin>plugin: Option<ListconfigsConfigsPlugin>plugin_dir: Option<ListconfigsConfigsPlugindir>lightning_dir: Option<ListconfigsConfigsLightningdir>network: Option<ListconfigsConfigsNetwork>allow_deprecated_apis: Option<ListconfigsConfigsAllowdeprecatedapis>rpc_file: Option<ListconfigsConfigsRpcfile>disable_plugin: Option<ListconfigsConfigsDisableplugin>always_use_proxy: Option<ListconfigsConfigsAlwaysuseproxy>daemon: Option<ListconfigsConfigsDaemon>wallet: Option<ListconfigsConfigsWallet>large_channels: Option<ListconfigsConfigsLargechannels>experimental_dual_fund: Option<ListconfigsConfigsExperimentaldualfund>experimental_splicing: Option<ListconfigsConfigsExperimentalsplicing>experimental_onion_messages: Option<ListconfigsConfigsExperimentalonionmessages>experimental_offers: Option<ListconfigsConfigsExperimentaloffers>experimental_shutdown_wrong_funding: Option<ListconfigsConfigsExperimentalshutdownwrongfunding>experimental_peer_storage: Option<ListconfigsConfigsExperimentalpeerstorage>experimental_anchors: Option<ListconfigsConfigsExperimentalanchors>database_upgrade: Option<ListconfigsConfigsDatabaseupgrade>rgb: Option<ListconfigsConfigsRgb>alias: Option<ListconfigsConfigsAlias>pid_file: Option<ListconfigsConfigsPidfile>ignore_fee_limits: Option<ListconfigsConfigsIgnorefeelimits>watchtime_blocks: Option<ListconfigsConfigsWatchtimeblocks>max_locktime_blocks: Option<ListconfigsConfigsMaxlocktimeblocks>funding_confirms: Option<ListconfigsConfigsFundingconfirms>cltv_delta: Option<ListconfigsConfigsCltvdelta>cltv_final: Option<ListconfigsConfigsCltvfinal>commit_time: Option<ListconfigsConfigsCommittime>fee_base: Option<ListconfigsConfigsFeebase>rescan: Option<ListconfigsConfigsRescan>fee_per_satoshi: Option<ListconfigsConfigsFeepersatoshi>max_concurrent_htlcs: Option<ListconfigsConfigsMaxconcurrenthtlcs>htlc_minimum_msat: Option<ListconfigsConfigsHtlcminimummsat>htlc_maximum_msat: Option<ListconfigsConfigsHtlcmaximummsat>max_dust_htlc_exposure_msat: Option<ListconfigsConfigsMaxdusthtlcexposuremsat>min_capacity_sat: Option<ListconfigsConfigsMincapacitysat>addr: Option<ListconfigsConfigsAddr>announce_addr: Option<ListconfigsConfigsAnnounceaddr>bind_addr: Option<ListconfigsConfigsBindaddr>offline: Option<ListconfigsConfigsOffline>autolisten: Option<ListconfigsConfigsAutolisten>proxy: Option<ListconfigsConfigsProxy>disable_dns: Option<ListconfigsConfigsDisabledns>announce_addr_discovered: Option<ListconfigsConfigsAnnounceaddrdiscovered>announce_addr_discovered_port: Option<ListconfigsConfigsAnnounceaddrdiscoveredport>encrypted_hsm: Option<ListconfigsConfigsEncryptedhsm>rpc_file_mode: Option<ListconfigsConfigsRpcfilemode>log_level: Option<ListconfigsConfigsLoglevel>log_prefix: Option<ListconfigsConfigsLogprefix>log_file: Option<ListconfigsConfigsLogfile>log_timestamps: Option<ListconfigsConfigsLogtimestamps>force_feerates: Option<ListconfigsConfigsForcefeerates>subdaemon: Option<ListconfigsConfigsSubdaemon>fetchinvoice_noconnect: Option<ListconfigsConfigsFetchinvoicenoconnect>accept_htlc_tlv_types: Option<ListconfigsConfigsAccepthtlctlvtypes>tor_service_password: Option<ListconfigsConfigsTorservicepassword>announce_addr_dns: Option<ListconfigsConfigsAnnounceaddrdns>require_confirmed_inputs: Option<ListconfigsConfigsRequireconfirmedinputs>commit_fee: Option<ListconfigsConfigsCommitfee>commit_feerate_offset: Option<ListconfigsConfigsCommitfeerateoffset>autoconnect_seeker_peers: Option<ListconfigsConfigsAutoconnectseekerpeers>Trait Implementations
Sourceimpl Clone for ListconfigsConfigs
impl Clone for ListconfigsConfigs
Sourcefn clone(&self) -> ListconfigsConfigs
fn clone(&self) -> ListconfigsConfigs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListconfigsConfigs
impl Debug for ListconfigsConfigs
Sourceimpl Default for ListconfigsConfigs
impl Default for ListconfigsConfigs
Sourcefn default() -> ListconfigsConfigs
fn default() -> ListconfigsConfigs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ListconfigsConfigs
impl<'de> Deserialize<'de> for ListconfigsConfigs
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ListconfigsConfigs, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ListconfigsConfigs, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ListconfigsConfigs
impl Message for ListconfigsConfigs
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ListconfigsConfigs
impl PartialEq for ListconfigsConfigs
Sourceimpl Serialize for ListconfigsConfigs
impl Serialize for ListconfigsConfigs
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ListconfigsConfigs