pub struct State { /* private fields */ }Implementations
Sourceimpl State
impl State
pub fn new() -> Self
pub fn len(&self) -> usize
Sourcepub fn merge(&mut self, other: &State) -> Result<MergeResult>
pub fn merge(&mut self, other: &State) -> Result<MergeResult>
Merge incoming state and track potential version conflicts.
A conflict means the incoming state is stale or incompatible with local tombstone knowledge. Callers may use this signal to trigger a full sync.
pub fn diff(&self, other: &State) -> Result<Vec<StateChange>>
Sourcepub fn diff_state(&self, other: &State) -> State
pub fn diff_state(&self, other: &State) -> State
Return a State containing only entries that are newer in other than in self.
This is useful for sending compact state diffs.
Sourcepub fn resign_signatures<F>(&mut self, signer: F) -> Result<usize>
pub fn resign_signatures<F>(&mut self, signer: F) -> Result<usize>
Sign entries missing signatures and return how many signatures were added.
pub fn sketch(&self) -> StateSketch
pub fn omit_tombstones(&self) -> State