pub struct RuneFactory;Expand description
A factory responsible for carving runes.
RuneFactory provides utility functions to manipulate and produce runes
with certain characteristics, such as additional restrictions.
Implementations
Sourceimpl RuneFactory
impl RuneFactory
Sourcepub fn carve<T: Restrictor + Copy>(
origin: &Rune,
append: &[T],
) -> Result<String, RuneError>
pub fn carve<T: Restrictor + Copy>( origin: &Rune, append: &[T], ) -> Result<String, RuneError>
Combines an original Rune with a list of restricters,
and produces a new rune in base64 format.
Parameters
origin: A reference to the originalRunethat will serve as the base.append: AVeccontaining entities that implement theRestrictortrait.
Returns
A Result containing a String representing the carved rune in base64 format.
In the event of any failure during the carving process, returns a RuneError.